# Base Imports
import logging

# Libraries
import pandas as pd

# SqlAlchemy Imports
from sqlalchemy.orm import Session
from sqlalchemy import create_engine
from sqlalchemy.exc import IntegrityError


class HoodatSqlalchemy():

    def __init__(self, sqlalchemy_database_uri):
        self.sqlalchemy_database_uri = sqlalchemy_database_uri
        self.engine = create_engine(self.sqlalchemy_database_uri)

    def commit_pandas_df(self, df, table, record_func):
        session = Session(self.engine)
        logging.info(
            f"Populating {table} table")
        n_rows = df.shape[0]
        logging.info(f"Total rows: {n_rows}")
        for i in range(n_rows):
            x = df.iloc[i]
            try:
                record = record_func(x)
                session.add(record)
                session.flush()
            except IntegrityError as e:
                logging.info("Record already exists in db")
                logging.info(e)
                session.rollback()
            else:
                logging.info("Adding row")
                session.commit()
        session.close()



#!/usr/bin/env python

from setuptools import setup

setup(
    name='hoodat_utils',
    packages=['hoodat_utils'],
    version='0.0.1',
    license='MIT',
    description=
    'Utilities for hoodat',
    author='Eugene Brown',
    author_email='efbbrown@gmail.com',
    url='https://github.com/efbbrown/hoodat_utils',
    install_requires=[
        'pickle',
        'matplotlib',
        'sqlalchemy',
        'numpy',
        'scikit-learn',
        'pandas',
        'boto3'
    ],
    # download_url="https://github.com/efbbrown/hoodat_utils/archive/v.0.0.1-alpha.tar.gz",
    include_package_data=True)